@@ -37,7 +37,7 @@ proc parse_env_dir {args} {
             continue
         }
 
-        set flist [concat $flist [glob $dirname/*]]
+        set flist [concat $flist [glob -nocomplain $dirname/*]]
     }
 
     # sort based on tail name
@@ -107,7 +107,7 @@ proc parse_env {fname} {
 
 proc env_parse_test {} {
 
-    foreach f [glob environ/*] {
+    foreach f [glob -nocomplain environ/*] {
         lappend envdata [parse_env $f]
     }
 
